Authors
===============

* __[Isaac Elbaz](https://github.com/script3r)__

    @script3r is the current maintainer of the code and has written much of the
    current code base, including a complete refactor to make use of Google Tink instead of Fernet cryptography. This work has been largely based of [Django Fernet Fields](https://github.com/orcasgit/django-fernet-fields) which seems to have been abandoned.
